@@ -17,8 +17,18 @@
 
 package constant
 
-// nolint
 const (
-	FAILOVER_CLUSTER_NAME  = "failover"
-	ZONEAWARE_CLUSTER_NAME = "zoneAware"
+	ClusterKeyAvailable       = "available"
+	ClusterKeyBroadcast       = "broadcast"
+	ClusterKeyFailback        = "failback"
+	ClusterKeyFailfast        = "failfast"
+	ClusterKeyFailover        = "failover"
+	ClusterKeyFailsafe        = "failsafe"
+	ClusterKeyForking         = "forking"
+	ClusterKeyZoneAware       = "zoneAware"
+	ClusterKeyAdaptiveService = "adaptiveService"
+)
+
+const (
+	NonImportErrorMsgFormat = "Cluster for %s is not existing, make sure you have import the package."
 )
