@@ -18,10 +18,7 @@
 package constant
 
 const (
-	// Version apache/dubbo-go version
-	Version = "3.0.0"
-	// Name module name
-	Name = "dubbogo"
-	// Date release date
-	DATE = "2021/05/14"
+	Version = "3.0.0"      // apache/dubbo-go version
+	Name    = "dubbogo"    // module name
+	DATE    = "2021/05/14" // release date
 )
