@@ -18,12 +18,10 @@
 package extension
 
 import (
-	"github.com/apache/dubbo-go/protocol/rest/client"
+	"dubbo.apache.org/dubbo-go/v3/protocol/rest/client"
 )
 
-var (
-	restClients = make(map[string]func(restOptions *client.RestOptions) client.RestClient, 8)
-)
+var restClients = make(map[string]func(restOptions *client.RestOptions) client.RestClient, 8)
 
 // SetRestClient sets the RestClient with @name
 func SetRestClient(name string, fun func(_ *client.RestOptions) client.RestClient) {
