@@ -18,12 +18,10 @@
 package extension
 
 import (
-	"github.com/apache/dubbo-go/protocol/rest/server"
+	"dubbo.apache.org/dubbo-go/v3/protocol/rest/server"
 )
 
-var (
-	restServers = make(map[string]func() server.RestServer, 8)
-)
+var restServers = make(map[string]func() server.RestServer, 8)
 
 // SetRestServer sets the RestServer with @name
 func SetRestServer(name string, fun func() server.RestServer) {
