@@ -24,9 +24,11 @@ import (
 
 var (
 	// ShutdownSignals receives shutdown signals to process
-	ShutdownSignals = []os.Signal{os.Interrupt, os.Kill, syscall.SIGKILL,
+	ShutdownSignals = []os.Signal{
+		os.Interrupt, os.Kill, syscall.SIGKILL,
 		syscall.SIGHUP, syscall.SIGINT, syscall.SIGQUIT, syscall.SIGILL, syscall.SIGTRAP,
-		syscall.SIGABRT, syscall.SIGTERM}
+		syscall.SIGABRT, syscall.SIGTERM,
+	}
 
 	// DumpHeapShutdownSignals receives shutdown signals to process
 	DumpHeapShutdownSignals = []os.Signal{syscall.SIGQUIT, syscall.SIGILL, syscall.SIGTRAP, syscall.SIGABRT}
