@@ -18,8 +18,8 @@
 package factory
 
 import (
-	"github.com/apache/dubbo-go/common"
-	"github.com/apache/dubbo-go/metadata/report"
+	"dubbo.apache.org/dubbo-go/v3/common"
+	"dubbo.apache.org/dubbo-go/v3/metadata/report"
 )
 
 // MetadataReportFactory interface will create metadata report
@@ -27,5 +27,4 @@ type MetadataReportFactory interface {
 	CreateMetadataReport(*common.URL) report.MetadataReport
 }
 
-type BaseMetadataReportFactory struct {
-}
+type BaseMetadataReportFactory struct{}
