@@ -129,7 +129,7 @@ func marshalRequest(encoder *hessian.Encoder, p DubboPackage) ([]byte, error) {
 		logger.Infof("request args are: %+v", request.Params)
 		return nil, perrors.Errorf("@params is not of type: []interface{}")
 	}
-	types, err := getArgsTypeList(args)
+	types, err := GetArgsTypeList(args)
 	if err != nil {
 		return nil, perrors.Wrapf(err, " PackRequest(args:%+v)", args)
 	}
@@ -392,7 +392,7 @@ func buildServerSidePackageBody(pkg *DubboPackage) {
 	}
 }
 
-func getArgsTypeList(args []interface{}) (string, error) {
+func GetArgsTypeList(args []interface{}) (string, error) {
 	var (
 		typ   string
 		types string
@@ -482,6 +482,22 @@ func getArgType(v interface{}) string {
 		return "java.util.Map"
 	case hessian.POJOEnum:
 		return v.(hessian.POJOEnum).JavaClassName()
+	case *int8:
+		return "java.lang.Byte"
+	case *int16:
+		return "java.lang.Short"
+	case *uint16:
+		return "java.lang.Character"
+	case *int:
+		return "java.lang.Long"
+	case *int32:
+		return "java.lang.Integer"
+	case *int64:
+		return "java.lang.Long"
+	case *float32:
+		return "java.lang.Float"
+	case *float64:
+		return "java.lang.Double"
 	//  Serialized tags for complex types
 	default:
 		t := reflect.TypeOf(v)
