@@ -18,11 +18,16 @@
 package invocation
 
 import (
+	"context"
 	"reflect"
 	"strings"
 	"sync"
 )
 
+import (
+	"google.golang.org/grpc/metadata"
+)
+
 import (
 	"dubbo.apache.org/dubbo-go/v3/common"
 	"dubbo.apache.org/dubbo-go/v3/common/constant"
@@ -129,7 +134,7 @@ func (r *RPCInvocation) Attachments() map[string]interface{} {
 	return r.attachments
 }
 
-// Attachment returns the corresponding value from dubbo's attachment with the given key.
+// GetAttachmentInterface returns the corresponding value from dubbo's attachment with the given key.
 func (r *RPCInvocation) GetAttachmentInterface(key string) interface{} {
 	r.lock.RLock()
 	defer r.lock.RUnlock()
@@ -186,24 +191,20 @@ func (r *RPCInvocation) GetAttachment(key string) (string, bool) {
 	if r.attachments == nil {
 		return "", false
 	}
-	if value, ok := r.attachments[key]; ok {
-		if str, ok := value.(string); ok {
+	if value, existed := r.attachments[key]; existed {
+		if str, strOK := value.(string); strOK {
 			return str, true
+		} else if strArr, strArrOK := value.([]string); strArrOK && len(strArr) > 0 {
+			// For triple protocol, the attachment value is wrapped by an array.
+			return strArr[0], true
 		}
 	}
 	return "", false
 }
 
 func (r *RPCInvocation) GetAttachmentWithDefaultValue(key string, defaultValue string) string {
-	r.lock.RLock()
-	defer r.lock.RUnlock()
-	if r.attachments == nil {
-		return defaultValue
-	}
-	if value, ok := r.attachments[key]; ok {
-		if str, ok := value.(string); ok {
-			return str
-		}
+	if value, ok := r.GetAttachment(key); ok {
+		return value
 	}
 	return defaultValue
 }
@@ -239,6 +240,22 @@ func (r *RPCInvocation) GetAttributeWithDefaultValue(key string, defaultValue in
 	return defaultValue
 }
 
+func (r *RPCInvocation) GetAttachmentAsContext() context.Context {
+	gRPCMD := make(metadata.MD, 0)
+	ctx := context.Background()
+	for k, v := range r.Attachments() {
+		if str, ok := v.(string); ok {
+			gRPCMD.Set(k, str)
+			continue
+		}
+		if str, ok := v.([]string); ok {
+			gRPCMD.Set(k, str...)
+			continue
+		}
+	}
+	return metadata.NewOutgoingContext(ctx, gRPCMD)
+}
+
 // /////////////////////////
 // option
 // /////////////////////////
