@@ -35,18 +35,12 @@ func init() {
 	rand.Seed(time.Now().UnixNano())
 }
 
-// ////////////////////////////////////////
-// service event
-// ////////////////////////////////////////
-
 // ServiceEvent includes create, update, delete event
 type ServiceEvent struct {
 	Action  remoting.EventType
 	Service *common.URL
-	// store the key for Service.Key()
-	key string
-	// If the url is updated, such as Merged.
-	updated bool
+	key     string // store the key for Service.Key()
+	updated bool   // If the url is updated, such as Merged.
 	KeyFunc KeyFunc
 }
 
@@ -55,19 +49,20 @@ func (e *ServiceEvent) String() string {
 	return fmt.Sprintf("ServiceEvent{Action{%s}, Path{%s}, Key{%s}}", e.Action, e.Service, e.key)
 }
 
-// Update() update the url with the merged URL. Work with Updated() can reduce the process of some merging URL.
+// Update updates the url with the merged URL. Work with Updated() can reduce the process
+// of some merging URL.
 func (e *ServiceEvent) Update(url *common.URL) {
 	e.Service = url
 	e.updated = true
 }
 
-// Updated() check if the url is updated.
-// If the serviceEvent is updated, then it don't need merge url again.
+// Updated checks if the url is updated. If the serviceEvent is updated, then it don't need
+// merge url again.
 func (e *ServiceEvent) Updated() bool {
 	return e.updated
 }
 
-// Key() generate the key for service.Key(). It is cached once.
+// Key generates the key for service.Key(). It is cached once.
 func (e *ServiceEvent) Key() string {
 	if len(e.key) > 0 {
 		return e.key
