@@ -21,6 +21,7 @@ import (
 	"context"
 	"strings"
 	"sync"
+	"time"
 )
 
 import (
@@ -30,18 +31,18 @@ import (
 )
 
 import (
-	"github.com/apache/dubbo-go/common"
-	"github.com/apache/dubbo-go/common/constant"
-	"github.com/apache/dubbo-go/common/extension"
-	"github.com/apache/dubbo-go/common/logger"
-	"github.com/apache/dubbo-go/config"
-	"github.com/apache/dubbo-go/config_center"
-	_ "github.com/apache/dubbo-go/config_center/configurator"
-	"github.com/apache/dubbo-go/protocol"
-	"github.com/apache/dubbo-go/protocol/protocolwrapper"
-	"github.com/apache/dubbo-go/registry"
-	_ "github.com/apache/dubbo-go/registry/directory"
-	"github.com/apache/dubbo-go/remoting"
+	"dubbo.apache.org/dubbo-go/v3/common"
+	"dubbo.apache.org/dubbo-go/v3/common/constant"
+	"dubbo.apache.org/dubbo-go/v3/common/extension"
+	"dubbo.apache.org/dubbo-go/v3/common/logger"
+	"dubbo.apache.org/dubbo-go/v3/config"
+	"dubbo.apache.org/dubbo-go/v3/config_center"
+	_ "dubbo.apache.org/dubbo-go/v3/config_center/configurator"
+	"dubbo.apache.org/dubbo-go/v3/protocol"
+	"dubbo.apache.org/dubbo-go/v3/protocol/protocolwrapper"
+	"dubbo.apache.org/dubbo-go/v3/registry"
+	_ "dubbo.apache.org/dubbo-go/v3/registry/directory"
+	"dubbo.apache.org/dubbo-go/v3/remoting"
 )
 
 var (
@@ -50,12 +51,11 @@ var (
 	reserveParams = []string{
 		"application", "codec", "exchanger", "serialization", "cluster", "connections", "deprecated", "group",
 		"loadbalance", "mock", "path", "timeout", "token", "version", "warmup", "weight", "timestamp", "dubbo",
-		"release", "interface",
+		"release", "interface", "registry.role",
 	}
 )
 
 type registryProtocol struct {
-	invokers []protocol.Invoker
 	// Registry Map<RegistryAddress, Registry>
 	registries *sync.Map
 	// To solve the problem of RMI repeated exposure port conflicts,
@@ -72,12 +72,6 @@ func init() {
 	extension.SetProtocol("registry", GetProtocol)
 }
 
-func getCacheKey(invoker protocol.Invoker) string {
-	url := getProviderUrl(invoker)
-	delKeys := gxset.NewSet("dynamic", "enabled")
-	return url.CloneExceptParams(delKeys).String()
-}
-
 func newRegistryProtocol() *registryProtocol {
 	return &registryProtocol{
 		registries: &sync.Map{},
@@ -85,13 +79,24 @@ func newRegistryProtocol() *registryProtocol {
 	}
 }
 
-func getRegistry(regUrl *common.URL) registry.Registry {
-	reg, err := extension.GetRegistry(regUrl.Protocol, regUrl)
-	if err != nil {
-		logger.Errorf("Registry can not connect success, program is going to panic.Error message is %s", err.Error())
-		panic(err.Error())
+func (proto *registryProtocol) getRegistry(registryUrl *common.URL) registry.Registry {
+	var err error
+	reg, loaded := proto.registries.Load(registryUrl.Location)
+	if !loaded {
+		reg, err = extension.GetRegistry(registryUrl.Protocol, registryUrl)
+		if err != nil {
+			logger.Errorf("Registry can not connect success, program is going to panic.Error message is %s", err.Error())
+			panic(err)
+		}
+		proto.registries.Store(registryUrl.Location, reg)
 	}
-	return reg
+	return reg.(registry.Registry)
+}
+
+func getCacheKey(invoker protocol.Invoker) string {
+	url := getProviderUrl(invoker)
+	delKeys := gxset.NewSet("dynamic", "enabled")
+	return url.CloneExceptParams(delKeys).String()
 }
 
 func getUrlToRegistry(providerUrl *common.URL, registryUrl *common.URL) *common.URL {
@@ -134,13 +139,13 @@ func (proto *registryProtocol) GetRegistries() []registry.Registry {
 
 // Refer provider service from registry center
 func (proto *registryProtocol) Refer(url *common.URL) protocol.Invoker {
-	var registryUrl = url
-	var serviceUrl = registryUrl.SubURL
-	if registryUrl.Protocol == constant.REGISTRY_PROTOCOL {
-		registryUrl.Protocol = registryUrl.GetParam(constant.REGISTRY_KEY, "")
+	registryUrl := url
+	serviceUrl := registryUrl.SubURL
+	if registryUrl.Protocol == constant.RegistryProtocol {
+		registryUrl.Protocol = registryUrl.GetParam(constant.RegistryKey, "")
 	}
 
-	reg := proto.getRegistry(registryUrl)
+	reg := proto.getRegistry(url)
 
 	// new registry directory for store service url from registry
 	directory, err := extension.GetDefaultRegistryDirectory(registryUrl, reg)
@@ -157,81 +162,81 @@ func (proto *registryProtocol) Refer(url *common.URL) protocol.Invoker {
 	}
 
 	// new cluster invoker
-	cluster := extension.GetCluster(serviceUrl.GetParam(constant.CLUSTER_KEY, constant.DEFAULT_CLUSTER))
+	clusterKey := serviceUrl.GetParam(constant.ClusterKey, constant.DefaultCluster)
+	cluster, err := extension.GetCluster(clusterKey)
+	if err != nil {
+		panic(err)
+	}
 	invoker := cluster.Join(directory)
-	proto.invokers = append(proto.invokers, invoker)
 	return invoker
 }
 
-func (proto *registryProtocol) getRegistry(registryUrl *common.URL) registry.Registry {
-	var reg registry.Registry
-	if regI, loaded := proto.registries.Load(registryUrl.Key()); !loaded {
-		reg = getRegistry(registryUrl)
-		proto.registries.Store(registryUrl.Key(), reg)
-	} else {
-		reg = regI.(registry.Registry)
-	}
-	return reg
-}
-
 // Export provider service to registry center
-func (proto *registryProtocol) Export(invoker protocol.Invoker) protocol.Exporter {
+func (proto *registryProtocol) Export(originInvoker protocol.Invoker) protocol.Exporter {
 	proto.once.Do(func() {
 		proto.initConfigurationListeners()
 	})
-	registryUrl := getRegistryUrl(invoker)
-	providerUrl := getProviderUrl(invoker)
+	registryUrl := getRegistryUrl(originInvoker)
+	providerUrl := getProviderUrl(originInvoker)
 
 	overriderUrl := getSubscribedOverrideUrl(providerUrl)
 	// Deprecated! subscribe to override rules in 2.6.x or before.
-	overrideSubscribeListener := newOverrideSubscribeListener(overriderUrl, invoker, proto)
+	overrideSubscribeListener := newOverrideSubscribeListener(overriderUrl, originInvoker, proto)
 	proto.overrideListeners.Store(overriderUrl, overrideSubscribeListener)
 	proto.providerConfigurationListener.OverrideUrl(providerUrl)
 	serviceConfigurationListener := newServiceConfigurationListener(overrideSubscribeListener, providerUrl)
 	proto.serviceConfigurationListeners.Store(providerUrl.ServiceKey(), serviceConfigurationListener)
 	serviceConfigurationListener.OverrideUrl(providerUrl)
 
-	var reg registry.Registry
-	if regI, loaded := proto.registries.Load(registryUrl.Key()); !loaded {
-		reg = getRegistry(registryUrl)
-		proto.registries.Store(registryUrl.Key(), reg)
-		logger.Infof("Export proto:%p registries address:%p", proto, proto.registries)
-	} else {
-		reg = regI.(registry.Registry)
-	}
+	// export invoker
+	exporter := proto.doLocalExport(originInvoker, providerUrl)
 
-	registeredProviderUrl := getUrlToRegistry(providerUrl, registryUrl)
-	err := reg.Register(registeredProviderUrl)
-	if err != nil {
-		logger.Errorf("provider service %v register registry %v error, error message is %s",
-			providerUrl.Key(), registryUrl.Key(), err.Error())
-		return nil
-	}
+	if len(registryUrl.Protocol) > 0 {
+		// url to registry
+		reg := proto.getRegistry(registryUrl)
+		registeredProviderUrl := getUrlToRegistry(providerUrl, registryUrl)
 
-	key := getCacheKey(invoker)
-	logger.Infof("The cached exporter keys is %v!", key)
-	cachedExporter, loaded := proto.bounds.Load(key)
-	if loaded {
-		logger.Infof("The exporter has been cached, and will return cached exporter!")
-	} else {
-		wrappedInvoker := newWrappedInvoker(invoker, providerUrl)
-		cachedExporter = extension.GetProtocol(protocolwrapper.FILTER).Export(wrappedInvoker)
-		proto.bounds.Store(key, cachedExporter)
-		logger.Infof("The exporter has not been cached, and will return a new exporter!")
-	}
-
-	go func() {
-		if err = reg.Subscribe(overriderUrl, overrideSubscribeListener); err != nil {
-			logger.Warnf("reg.subscribe(overriderUrl:%v) = error:%v", overriderUrl, err)
+		err := reg.Register(registeredProviderUrl)
+		if err != nil {
+			logger.Errorf("provider service %v register registry %v error, error message is %s",
+				providerUrl.Key(), registryUrl.Key(), err.Error())
+			return nil
 		}
-	}()
-	return cachedExporter.(protocol.Exporter)
+
+		go func() {
+			if err := reg.Subscribe(overriderUrl, overrideSubscribeListener); err != nil {
+				logger.Warnf("reg.subscribe(overriderUrl:%v) = error:%v", overriderUrl, err)
+			}
+		}()
+
+		exporter.SetRegisterUrl(registeredProviderUrl)
+		exporter.SetSubscribeUrl(overriderUrl)
+
+	} else {
+		logger.Warnf("provider service %v do not regist to registry %v. possible direct connection provider",
+			providerUrl.Key(), registryUrl.Key())
+	}
+
+	return exporter
+}
+
+func (proto *registryProtocol) doLocalExport(originInvoker protocol.Invoker, providerUrl *common.URL) *exporterChangeableWrapper {
+	key := getCacheKey(originInvoker)
+	cachedExporter, loaded := proto.bounds.Load(key)
+	if !loaded {
+		// new Exporter
+		invokerDelegate := newInvokerDelegate(originInvoker, providerUrl)
+		cachedExporter = newExporterChangeableWrapper(originInvoker,
+			extension.GetProtocol(protocolwrapper.FILTER).Export(invokerDelegate))
+		proto.bounds.Store(key, cachedExporter)
+	}
+	return cachedExporter.(*exporterChangeableWrapper)
 }
 
 func (proto *registryProtocol) reExport(invoker protocol.Invoker, newUrl *common.URL) {
 	key := getCacheKey(invoker)
 	if oldExporter, loaded := proto.bounds.Load(key); loaded {
-		wrappedNewInvoker := newWrappedInvoker(invoker, newUrl)
+		wrappedNewInvoker := newInvokerDelegate(invoker, newUrl)
 		oldExporter.(protocol.Exporter).Unexport()
 		proto.bounds.Delete(key)
 		// oldExporter Unexport function unRegister rpcService from the serviceMap, so need register it again as far as possible
@@ -247,7 +252,7 @@ func registerServiceMap(invoker protocol.Invoker) error {
 	providerUrl := getProviderUrl(invoker)
 	// the bean.name param of providerUrl is the ServiceConfig id property
 	// such as dubbo://:20000/org.apache.dubbo.UserProvider?bean.name=UserProvider&cluster=failfast...
-	id := providerUrl.GetParam(constant.BEAN_NAME_KEY, "")
+	id := providerUrl.GetParam(constant.BeanNameKey, "")
 
 	serviceConfig := config.GetProviderConfig().Services[id]
 	if serviceConfig == nil {
@@ -260,8 +265,9 @@ func registerServiceMap(invoker protocol.Invoker) error {
 		return perrors.New(s)
 	}
 
-	_, err := common.ServiceMap.Register(serviceConfig.InterfaceName,
-		serviceConfig.Protocol, serviceConfig.Group,
+	_, err := common.ServiceMap.Register(serviceConfig.Interface,
+		// FIXME
+		serviceConfig.ProtocolIDs[0], serviceConfig.Group,
 		serviceConfig.Version, rpcService)
 	if err != nil {
 		s := "reExport can not re register ServiceMap. Error message is " + err.Error()
@@ -330,51 +336,51 @@ func (nl *overrideSubscribeListener) doOverrideIfNecessary() {
 
 func isMatched(providerUrl *common.URL, consumerUrl *common.URL) bool {
 	// Compatible with the 2.6.x
-	if len(providerUrl.GetParam(constant.CATEGORY_KEY, "")) == 0 &&
-		providerUrl.Protocol == constant.OVERRIDE_PROTOCOL {
-		providerUrl.AddParam(constant.CATEGORY_KEY, constant.CONFIGURATORS_CATEGORY)
+	if len(providerUrl.GetParam(constant.CategoryKey, "")) == 0 &&
+		providerUrl.Protocol == constant.OverrideProtocol {
+		providerUrl.AddParam(constant.CategoryKey, constant.ConfiguratorsCategory)
 	}
-	consumerInterface := consumerUrl.GetParam(constant.INTERFACE_KEY, consumerUrl.Path)
-	providerInterface := providerUrl.GetParam(constant.INTERFACE_KEY, providerUrl.Path)
+	consumerInterface := consumerUrl.GetParam(constant.InterfaceKey, consumerUrl.Path)
+	providerInterface := providerUrl.GetParam(constant.InterfaceKey, providerUrl.Path)
 
-	if !(constant.ANY_VALUE == consumerInterface ||
-		constant.ANY_VALUE == providerInterface ||
+	if !(constant.AnyValue == consumerInterface ||
+		constant.AnyValue == providerInterface ||
 		providerInterface == consumerInterface) {
 		return false
 	}
 
-	if !isMatchCategory(providerUrl.GetParam(constant.CATEGORY_KEY, constant.DEFAULT_CATEGORY),
-		consumerUrl.GetParam(constant.CATEGORY_KEY, constant.DEFAULT_CATEGORY)) {
+	if !isMatchCategory(providerUrl.GetParam(constant.CategoryKey, constant.DefaultCategory),
+		consumerUrl.GetParam(constant.CategoryKey, constant.DefaultCategory)) {
 		return false
 	}
 
-	if !providerUrl.GetParamBool(constant.ENABLED_KEY, true) &&
-		consumerUrl.GetParam(constant.ENABLED_KEY, "") != constant.ANY_VALUE {
+	if !providerUrl.GetParamBool(constant.EnabledKey, true) &&
+		consumerUrl.GetParam(constant.EnabledKey, "") != constant.AnyValue {
 		return false
 	}
-	consumerGroup := consumerUrl.GetParam(constant.GROUP_KEY, "")
-	consumerVersion := consumerUrl.GetParam(constant.VERSION_KEY, "")
-	consumerClassifier := consumerUrl.GetParam(constant.CLASSIFIER_KEY, "")
+	consumerGroup := consumerUrl.GetParam(constant.GroupKey, "")
+	consumerVersion := consumerUrl.GetParam(constant.VersionKey, "")
+	consumerClassifier := consumerUrl.GetParam(constant.ClassifierKey, "")
 
-	providerGroup := providerUrl.GetParam(constant.GROUP_KEY, "")
-	providerVersion := providerUrl.GetParam(constant.VERSION_KEY, "")
-	providerClassifier := providerUrl.GetParam(constant.CLASSIFIER_KEY, "")
+	providerGroup := providerUrl.GetParam(constant.GroupKey, "")
+	providerVersion := providerUrl.GetParam(constant.VersionKey, "")
+	providerClassifier := providerUrl.GetParam(constant.ClassifierKey, "")
 	// todo: public static boolean isContains(String values, String value) {
-	//        return isNotEmpty(values) && isContains(COMMA_SPLIT_PATTERN.split(values), value);
+	//        return isNotEmpty(values) && isContains(CommaSplitPattern.split(values), value);
 	//    }
-	return (consumerGroup == constant.ANY_VALUE || consumerGroup == providerGroup ||
-		strings.Contains(consumerGroup, providerGroup)) && (consumerVersion == constant.ANY_VALUE ||
+	return (consumerGroup == constant.AnyValue || consumerGroup == providerGroup ||
+		strings.Contains(consumerGroup, providerGroup)) && (consumerVersion == constant.AnyValue ||
 		consumerVersion == providerVersion) && (len(consumerClassifier) == 0 ||
-		consumerClassifier == constant.ANY_VALUE || consumerClassifier == providerClassifier)
+		consumerClassifier == constant.AnyValue || consumerClassifier == providerClassifier)
 }
 
 func isMatchCategory(category string, categories string) bool {
 	if len(categories) == 0 {
-		return category == constant.DEFAULT_CATEGORY
-	} else if strings.Contains(categories, constant.ANY_VALUE) {
+		return category == constant.DefaultCategory
+	} else if strings.Contains(categories, constant.AnyValue) {
 		return true
-	} else if strings.Contains(categories, constant.REMOVE_VALUE_PREFIX) {
-		return !strings.Contains(categories, constant.REMOVE_VALUE_PREFIX+category)
+	} else if strings.Contains(categories, constant.RemoveValuePrefix) {
+		return !strings.Contains(categories, constant.RemoveValuePrefix+category)
 	} else {
 		return strings.Contains(categories, category)
 	}
@@ -382,29 +388,37 @@ func isMatchCategory(category string, categories string) bool {
 
 func getSubscribedOverrideUrl(providerUrl *common.URL) *common.URL {
 	newUrl := providerUrl.Clone()
-	newUrl.Protocol = constant.PROVIDER_PROTOCOL
-	newUrl.SetParam(constant.CATEGORY_KEY, constant.CONFIGURATORS_CATEGORY)
-	newUrl.SetParam(constant.CHECK_KEY, "false")
+	newUrl.Protocol = constant.ProviderProtocol
+	newUrl.SetParam(constant.CategoryKey, constant.ConfiguratorsCategory)
+	newUrl.SetParam(constant.CheckKey, "false")
 	return newUrl
 }
 
 // Destroy registry protocol
 func (proto *registryProtocol) Destroy() {
-	for _, ivk := range proto.invokers {
-		ivk.Destroy()
-	}
-	proto.invokers = []protocol.Invoker{}
 	proto.bounds.Range(func(key, value interface{}) bool {
-		exporter := value.(protocol.Exporter)
-		exporter.Unexport()
-		proto.bounds.Delete(key)
+		// protocol holds the exporters actually, instead, registry holds them in order to avoid export repeatedly, so
+		// the work for unexport should be finished in protocol.Unexport(), see also config.destroyProviderProtocols().
+		exporter := value.(*exporterChangeableWrapper)
+		reg := proto.getRegistry(getRegistryUrl(exporter.originInvoker))
+		if err := reg.UnRegister(exporter.registerUrl); err != nil {
+			panic(err)
+		}
+		// TODO unsubscribeUrl
+
+		// close all protocol server after consumerUpdateWait + stepTimeout(max time wait during
+		// waitAndAcceptNewRequests procedure)
+		go func() {
+			select {
+			case <-time.After(config.GetShutDown().GetStepTimeout() + config.GetShutDown().GetConsumerUpdateWaitTime()):
+				exporter.Unexport()
+				proto.bounds.Delete(key)
+			}
+		}()
 		return true
 	})
+
 	proto.registries.Range(func(key, value interface{}) bool {
-		reg := value.(registry.Registry)
-		if reg.IsAvailable() {
-			reg.Destroy()
-		}
 		proto.registries.Delete(key)
 		return true
 	})
@@ -414,8 +428,8 @@ func getRegistryUrl(invoker protocol.Invoker) *common.URL {
 	// here add * for return a new url
 	url := invoker.GetURL()
 	// if the protocol == registry, set protocol the registry value in url.params
-	if url.Protocol == constant.REGISTRY_PROTOCOL {
-		url.Protocol = url.GetParam(constant.REGISTRY_KEY, "")
+	if url.Protocol == constant.RegistryProtocol {
+		url.Protocol = url.GetParam(constant.RegistryKey, "")
 	}
 	return url
 }
@@ -438,23 +452,54 @@ func GetProtocol() protocol.Protocol {
 	return regProtocol
 }
 
-type wrappedInvoker struct {
+type invokerDelegate struct {
 	invoker protocol.Invoker
 	protocol.BaseInvoker
 }
 
-func newWrappedInvoker(invoker protocol.Invoker, url *common.URL) *wrappedInvoker {
-	return &wrappedInvoker{
+func newInvokerDelegate(invoker protocol.Invoker, url *common.URL) *invokerDelegate {
+	return &invokerDelegate{
 		invoker:     invoker,
 		BaseInvoker: *protocol.NewBaseInvoker(url),
 	}
 }
 
 // Invoke remote service base on URL of wrappedInvoker
-func (ivk *wrappedInvoker) Invoke(ctx context.Context, invocation protocol.Invocation) protocol.Result {
+func (ivk *invokerDelegate) Invoke(ctx context.Context, invocation protocol.Invocation) protocol.Result {
 	return ivk.invoker.Invoke(ctx, invocation)
 }
 
+type exporterChangeableWrapper struct {
+	protocol.Exporter
+	originInvoker protocol.Invoker
+	exporter      protocol.Exporter
+	registerUrl   *common.URL
+	subscribeUrl  *common.URL
+}
+
+func (e *exporterChangeableWrapper) Unexport() {
+	e.exporter.Unexport()
+}
+
+func (e *exporterChangeableWrapper) SetRegisterUrl(registerUrl *common.URL) {
+	e.registerUrl = registerUrl
+}
+
+func (e *exporterChangeableWrapper) SetSubscribeUrl(subscribeUrl *common.URL) {
+	e.subscribeUrl = subscribeUrl
+}
+
+func (e *exporterChangeableWrapper) GetInvoker() protocol.Invoker {
+	return e.exporter.GetInvoker()
+}
+
+func newExporterChangeableWrapper(originInvoker protocol.Invoker, exporter protocol.Exporter) *exporterChangeableWrapper {
+	return &exporterChangeableWrapper{
+		originInvoker: originInvoker,
+		exporter:      exporter,
+	}
+}
+
 type providerConfigurationListener struct {
 	registry.BaseConfigurationListener
 	overrideListeners *sync.Map
@@ -464,7 +509,7 @@ func newProviderConfigurationListener(overrideListeners *sync.Map) *providerConf
 	listener := &providerConfigurationListener{}
 	listener.overrideListeners = overrideListeners
 	listener.InitWith(
-		config.GetProviderConfig().ApplicationConfig.Name+constant.CONFIGURATORS_SUFFIX,
+		config.GetRootConfig().Application.Name+constant.ConfiguratorSuffix,
 		listener,
 		extension.GetDefaultConfiguratorFunc(),
 	)
@@ -489,7 +534,7 @@ type serviceConfigurationListener struct {
 func newServiceConfigurationListener(overrideListener *overrideSubscribeListener, providerUrl *common.URL) *serviceConfigurationListener {
 	listener := &serviceConfigurationListener{overrideListener: overrideListener, providerUrl: providerUrl}
 	listener.InitWith(
-		providerUrl.EncodedServiceKey()+constant.CONFIGURATORS_SUFFIX,
+		providerUrl.EncodedServiceKey()+constant.ConfiguratorSuffix,
 		listener,
 		extension.GetDefaultConfiguratorFunc(),
 	)
