@@ -18,11 +18,11 @@
 package instance
 
 import (
-	"github.com/apache/dubbo-go/common"
-	"github.com/apache/dubbo-go/registry"
+	"dubbo.apache.org/dubbo-go/v3/common"
+	"dubbo.apache.org/dubbo-go/v3/registry"
 )
 
 type ServiceInstanceSelector interface {
-	//Select an instance of ServiceInstance by the specified ServiceInstance service instances
+	// Select an instance of ServiceInstance by the specified ServiceInstance service instances
 	Select(url *common.URL, serviceInstances []registry.ServiceInstance) registry.ServiceInstance
 }
