@@ -18,7 +18,6 @@
 package getty
 
 import (
-	"fmt"
 	"sync"
 	"sync/atomic"
 	"time"
@@ -41,10 +40,8 @@ import (
 	"dubbo.apache.org/dubbo-go/v3/remoting"
 )
 
-// todo: WritePkg_Timeout will entry *.yml
 const (
-	// WritePkg_Timeout the timeout of write pkg
-	WritePkg_Timeout = 5 * time.Second
+	WritePkg_Timeout = 5 * time.Second // TODO: WritePkg_Timeout will entry *.yml
 )
 
 var (
@@ -65,10 +62,6 @@ func (s *rpcSession) GetReqNum() int32 {
 	return atomic.LoadInt32(&s.reqNum)
 }
 
-// //////////////////////////////////////////
-// RpcClientHandler
-// //////////////////////////////////////////
-
 // nolint
 type RpcClientHandler struct {
 	conn         *gettyRPCClient
@@ -100,8 +93,8 @@ func (h *RpcClientHandler) OnClose(session getty.Session) {
 
 // OnMessage get response from getty server, and update the session to the getty client session list
 func (h *RpcClientHandler) OnMessage(session getty.Session, pkg interface{}) {
-	result, ok := pkg.(remoting.DecodeResult)
-	if !ok {
+	result, ok := pkg.(*remoting.DecodeResult)
+	if !ok || result == ((*remoting.DecodeResult)(nil)) {
 		logger.Errorf("[RpcClientHandler.OnMessage] getty client gets an unexpected rpc result: %#v", result)
 		return
 	}
@@ -174,10 +167,6 @@ func (h *RpcClientHandler) OnCron(session getty.Session) {
 	}
 }
 
-// //////////////////////////////////////////
-// RpcServerHandler
-// //////////////////////////////////////////
-
 // nolint
 type RpcServerHandler struct {
 	maxSessionNum  int
@@ -242,8 +231,8 @@ func (h *RpcServerHandler) OnMessage(session getty.Session, pkg interface{}) {
 	}
 	h.rwlock.Unlock()
 
-	decodeResult, drOK := pkg.(remoting.DecodeResult)
-	if !drOK {
+	decodeResult, drOK := pkg.(*remoting.DecodeResult)
+	if !drOK || decodeResult == ((*remoting.DecodeResult)(nil)) {
 		logger.Errorf("illegal package{%#v}", pkg)
 		return
 	}
@@ -275,27 +264,6 @@ func (h *RpcServerHandler) OnMessage(session getty.Session, pkg interface{}) {
 		return
 	}
 
-	defer func() {
-		if e := recover(); e != nil {
-			resp.Status = hessian.Response_SERVER_ERROR
-			if err, ok := e.(error); ok {
-				logger.Errorf("OnMessage panic: %+v", perrors.WithStack(err))
-				resp.Error = perrors.WithStack(err)
-			} else if err, ok := e.(string); ok {
-				logger.Errorf("OnMessage panic: %+v", perrors.New(err))
-				resp.Error = perrors.New(err)
-			} else {
-				logger.Errorf("OnMessage panic: %+v, this is impossible.", e)
-				resp.Error = fmt.Errorf("OnMessage panic unknow exception. %+v", e)
-			}
-
-			if !req.TwoWay {
-				return
-			}
-			reply(session, resp)
-		}
-	}()
-
 	invoc, ok := req.Data.(*invocation.RPCInvocation)
 	if !ok {
 		panic("create invocation occur some exception for the type is not suitable one.")
@@ -309,6 +277,7 @@ func (h *RpcServerHandler) OnMessage(session getty.Session, pkg interface{}) {
 		return
 	}
 	resp.Result = result
+
 	reply(session, resp)
 }
 
