@@ -18,20 +18,18 @@
 package getty
 
 import (
-	"errors"
 	"reflect"
 )
 
 import (
 	"github.com/apache/dubbo-getty"
 
-	hessian "github.com/apache/dubbo-go-hessian2"
-
 	perrors "github.com/pkg/errors"
 )
 
 import (
 	"dubbo.apache.org/dubbo-go/v3/common/logger"
+	"dubbo.apache.org/dubbo-go/v3/protocol/dubbo/impl"
 	"dubbo.apache.org/dubbo-go/v3/remoting"
 )
 
@@ -48,26 +46,30 @@ func NewRpcClientPackageHandler(client *Client) *RpcClientPackageHandler {
 // Read data from server. if the package size from server is larger than 4096 byte, server will read 4096 byte
 // and send to client each time. the Read can assemble it.
 func (p *RpcClientPackageHandler) Read(ss getty.Session, data []byte) (interface{}, int, error) {
-	resp, length, err := (p.client.codec).Decode(data)
-	// err := pkg.Unmarshal(buf, p.client)
+	rsp, length, err := (p.client.codec).Decode(data)
 	if err != nil {
-		if errors.Is(err, hessian.ErrHeaderNotEnough) || errors.Is(err, hessian.ErrBodyNotEnough) {
-			return nil, 0, nil
-		}
-
-		logger.Errorf("pkg.Unmarshal(ss:%+v, len(@data):%d) = error:%+v", ss, len(data), err)
-
+		err = perrors.WithStack(err)
+	}
+	if rsp == ((*remoting.DecodeResult)(nil)) {
 		return nil, length, err
 	}
-
-	return resp, length, nil
+	if rsp.Result == ((*remoting.Response)(nil)) || rsp.Result == ((*remoting.Request)(nil)) {
+		return nil, length, err
+	}
+	return rsp, length, err
 }
 
 // Write send the data to server
 func (p *RpcClientPackageHandler) Write(ss getty.Session, pkg interface{}) ([]byte, error) {
 	req, ok := pkg.(*remoting.Request)
+	maxBufLength := clientConf.GettySessionParam.MaxMsgLen + impl.HEADER_LENGTH
 	if ok {
 		buf, err := (p.client.codec).EncodeRequest(req)
+		bufLength := buf.Len()
+		if bufLength > maxBufLength {
+			logger.Errorf("Data length %d too large, max payload %d", bufLength-impl.HEADER_LENGTH, clientConf.GettySessionParam.MaxMsgLen)
+			return nil, perrors.Errorf("Data length %d too large, max payload %d", bufLength-impl.HEADER_LENGTH, clientConf.GettySessionParam.MaxMsgLen)
+		}
 		if err != nil {
 			logger.Warnf("binary.Write(req{%#v}) = err{%#v}", req, perrors.WithStack(err))
 			return nil, perrors.WithStack(err)
@@ -78,6 +80,11 @@ func (p *RpcClientPackageHandler) Write(ss getty.Session, pkg interface{}) ([]by
 	res, ok := pkg.(*remoting.Response)
 	if ok {
 		buf, err := (p.client.codec).EncodeResponse(res)
+		bufLength := buf.Len()
+		if bufLength > maxBufLength {
+			logger.Errorf("Data length %d too large, max payload %d", bufLength-impl.HEADER_LENGTH, clientConf.GettySessionParam.MaxMsgLen)
+			return nil, perrors.Errorf("Data length %d too large, max payload %d", bufLength-impl.HEADER_LENGTH, clientConf.GettySessionParam.MaxMsgLen)
+		}
 		if err != nil {
 			logger.Warnf("binary.Write(res{%#v}) = err{%#v}", req, perrors.WithStack(err))
 			return nil, perrors.WithStack(err)
@@ -102,25 +109,29 @@ func NewRpcServerPackageHandler(server *Server) *RpcServerPackageHandler {
 // and send to client each time. the Read can assemble it.
 func (p *RpcServerPackageHandler) Read(ss getty.Session, data []byte) (interface{}, int, error) {
 	req, length, err := (p.server.codec).Decode(data)
-	// resp,len, err := (*p.).DecodeResponse(buf)
 	if err != nil {
-		if errors.Is(err, hessian.ErrHeaderNotEnough) || errors.Is(err, hessian.ErrBodyNotEnough) {
-			return nil, 0, nil
-		}
-
-		logger.Errorf("pkg.Unmarshal(ss:%+v, len(@data):%d) = error:%+v", ss, len(data), err)
-
-		return nil, 0, err
+		err = perrors.WithStack(err)
+	}
+	if req == ((*remoting.DecodeResult)(nil)) {
+		return nil, length, err
+	}
+	if req.Result == ((*remoting.Request)(nil)) || req.Result == ((*remoting.Response)(nil)) {
+		return nil, length, err // as getty rule
 	}
-
 	return req, length, err
 }
 
 // Write send the data to client
 func (p *RpcServerPackageHandler) Write(ss getty.Session, pkg interface{}) ([]byte, error) {
 	res, ok := pkg.(*remoting.Response)
+	maxBufLength := srvConf.GettySessionParam.MaxMsgLen + impl.HEADER_LENGTH
 	if ok {
 		buf, err := (p.server.codec).EncodeResponse(res)
+		bufLength := buf.Len()
+		if bufLength > maxBufLength {
+			logger.Errorf("Data length %d too large, max payload %d", bufLength-impl.HEADER_LENGTH, srvConf.GettySessionParam.MaxMsgLen)
+			return nil, perrors.Errorf("Data length %d too large, max payload %d", bufLength-impl.HEADER_LENGTH, srvConf.GettySessionParam.MaxMsgLen)
+		}
 		if err != nil {
 			logger.Warnf("binary.Write(res{%#v}) = err{%#v}", res, perrors.WithStack(err))
 			return nil, perrors.WithStack(err)
@@ -131,6 +142,11 @@ func (p *RpcServerPackageHandler) Write(ss getty.Session, pkg interface{}) ([]by
 	req, ok := pkg.(*remoting.Request)
 	if ok {
 		buf, err := (p.server.codec).EncodeRequest(req)
+		bufLength := buf.Len()
+		if bufLength > maxBufLength {
+			logger.Errorf("Data length %d too large, max payload %d", bufLength-impl.HEADER_LENGTH, srvConf.GettySessionParam.MaxMsgLen)
+			return nil, perrors.Errorf("Data length %d too large, max payload %d", bufLength-impl.HEADER_LENGTH, srvConf.GettySessionParam.MaxMsgLen)
+		}
 		if err != nil {
 			logger.Warnf("binary.Write(req{%#v}) = err{%#v}", res, perrors.WithStack(err))
 			return nil, perrors.WithStack(err)
