@@ -26,19 +26,14 @@ type DataListener interface {
 	DataChange(event Event) bool // bool is return for interface implement is interesting
 }
 
-//////////////////////////////////////////
-// event type
-//////////////////////////////////////////
-
 // EventType means SourceObjectEventType
 type EventType int
 
 const (
 	// EventTypeAdd means add event
-	EventTypeAdd = iota
+	EventTypeAdd EventType = iota
 	// EventTypeDel means del event
 	EventTypeDel
-	// EventTypeUpdate means update event
 	EventTypeUpdate
 )
 
@@ -53,10 +48,6 @@ func (t EventType) String() string {
 	return serviceEventTypeStrings[t]
 }
 
-//////////////////////////////////////////
-// service event
-//////////////////////////////////////////
-
 // Event defines common elements for service event
 type Event struct {
 	Path    string
