@@ -84,25 +84,26 @@ func GetNacosConfig(url *common.URL) ([]nacosConstant.ServerConfig, nacosConstan
 		serverConfigs = append(serverConfigs, nacosConstant.ServerConfig{IpAddr: ip, Port: uint64(port), ContextPath: contextPath})
 	}
 
-	timeout := url.GetParamDuration(constant.TimeoutKey, constant.DefaultRegTimeout)
+	timeout := url.GetParamDuration(constant.NacosTimeout, constant.DefaultRegTimeout)
 
 	clientConfig := nacosConstant.ClientConfig{
-		TimeoutMs:           uint64(int32(timeout / time.Millisecond)),
-		NamespaceId:         url.GetParam(constant.NacosNamespaceID, ""),
-		Username:            url.GetParam(constant.NacosUsername, ""),
-		Password:            url.GetParam(constant.NacosPassword, ""),
-		BeatInterval:        url.GetParamInt(constant.NacosBeatIntervalKey, 5000),
-		AppName:             url.GetParam(constant.NacosAppNameKey, ""),
-		Endpoint:            url.GetParam(constant.NacosEndpoint, ""),
-		RegionId:            url.GetParam(constant.NacosRegionIDKey, ""),
-		AccessKey:           url.GetParam(constant.NacosAccessKey, ""),
-		SecretKey:           url.GetParam(constant.NacosSecretKey, ""),
-		OpenKMS:             url.GetParamBool(constant.NacosOpenKmsKey, false),
-		CacheDir:            url.GetParam(constant.NacosCacheDirKey, ""),
-		UpdateThreadNum:     url.GetParamByIntValue(constant.NacosUpdateThreadNumKey, 20),
-		NotLoadCacheAtStart: url.GetParamBool(constant.NacosNotLoadLocalCache, true),
-		LogDir:              url.GetParam(constant.NacosLogDirKey, ""),
-		LogLevel:            url.GetParam(constant.NacosLogLevelKey, "info"),
+		TimeoutMs:            uint64(int32(timeout / time.Millisecond)),
+		NamespaceId:          url.GetParam(constant.NacosNamespaceID, ""),
+		Username:             url.GetParam(constant.NacosUsername, ""),
+		Password:             url.GetParam(constant.NacosPassword, ""),
+		BeatInterval:         url.GetParamInt(constant.NacosBeatIntervalKey, 5000),
+		AppName:              url.GetParam(constant.NacosAppNameKey, ""),
+		Endpoint:             url.GetParam(constant.NacosEndpoint, ""),
+		RegionId:             url.GetParam(constant.NacosRegionIDKey, ""),
+		AccessKey:            url.GetParam(constant.NacosAccessKey, ""),
+		SecretKey:            url.GetParam(constant.NacosSecretKey, ""),
+		OpenKMS:              url.GetParamBool(constant.NacosOpenKmsKey, false),
+		CacheDir:             url.GetParam(constant.NacosCacheDirKey, ""),
+		UpdateThreadNum:      url.GetParamByIntValue(constant.NacosUpdateThreadNumKey, 20),
+		NotLoadCacheAtStart:  url.GetParamBool(constant.NacosNotLoadLocalCache, true),
+		LogDir:               url.GetParam(constant.NacosLogDirKey, ""),
+		LogLevel:             url.GetParam(constant.NacosLogLevelKey, "info"),
+		UpdateCacheWhenEmpty: url.GetParamBool(constant.NacosUpdateCacheWhenEmpty, false),
 	}
 	return serverConfigs, clientConfig, nil
 }
